#
# spec file for package stgit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           stgit
Version:        2.4.12
Release:        1.3
Summary:        Stacked GIT - Source Code Management Tool
License:        GPL-2.0-or-later
URL:            https://stacked-git.github.io
Source0:        stgit-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  asciidoc
BuildRequires:  cargo-packaging
BuildRequires:  git-core
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  pkgconfig(openssl)
Requires:       git-core
# Disable this line if you wish to support all platforms.
# In most situations, you will likely only target tier1 arches for user facing components.
ExclusiveArch:  %{rust_tier1_arches}

%description
Stacked Git, StGit for short, is an application for managing Git commits
as a stack of patches.
With a patch stack workflow, multiple patches can be developed
concurrently and efficiently, with each patch focused on a single
concern, resulting in both a clean Git commit history and improved
productivity.

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (stgit and bash)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (stgit and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (stgit and zsh)
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for %{name}.

%package emacs
Summary:        emacs plugin for for %{name}
Requires:       %{name} = %{version}
Requires:       emacs
Supplements:    (stgit and emacs)
BuildArch:      noarch

%description emacs
emacs command line completion support for %{name}.

%package vim-plugin
Summary:        VIM plugin for for %{name}
Requires:       %{name} = %{version}
Requires:       vim
Supplements:    (stgit and vim)
BuildArch:      noarch

%description vim-plugin
VIM command line completion support for %{name}.

%prep
%autosetup -p1 -a1

%build
%{cargo_build}

%install
%make_install prefix=%{_prefix} install-completion install-contrib install-man

%files
%doc AUTHORS.md README.md CHANGELOG.md
%license COPYING
%{_bindir}/stg
%{_mandir}/man1/stg*

%files bash-completion
%{_datadir}/bash-completion/completions/stg

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/stg.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_stg

%files emacs
%{_datadir}/emacs/site-lisp/stgit.el

%files vim-plugin
%dir %{_datadir}/vim
%dir %{_datadir}/vim/vimfiles
%dir %{_datadir}/vim/vimfiles/ftdetect
%dir %{_datadir}/vim/vimfiles/syntax
%{_datadir}/vim/vimfiles/ftdetect/stg.vim
%{_datadir}/vim/vimfiles/syntax/stg*.vim

%changelog
* Fri Sep 20 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.4.12:
  * fix(squash): preserve consensus author
  * chore: update changelog for 2.4.12
  * feat(push): revert overzealous modified status
  * chore: update windows-sys to 0.59.0
  * chore: update syn to 2.0.77
  * chore: update cc to 1.1.18
  * chore: update filetime to 0.2.25
  * chore: update schannel to 0.1.24
  * chore: update gix-path to 0.10.11
  * chore: update serde_json to 1.0.128
- Switch to _service for fetching sources
- Adresses boo#1230691 CVE-2024-45405
* Fri Jan 26 2024 Martin Pluskal <mpluskal@suse.com>
- Move completions and plugins to subpackages
* Thu Jan 18 2024 Mikhail Terekhov <termim@gmail.com>
- update to 2.4.2
  * This is a complete rewrite in Rust.
  * For the full list of changes see
    https://github.com/stacked-git/stgit/releases
- Drop no longer needed stgbashprompt-noexec.patch
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 1.5:
  * Add Makefile targets for installing shell completions
  * stg rebase --interactive learns ‘hide’ instruction
  * Picked patch names are preserved when possible (#175)
  * Replace --unapplied option with --noapply for stg pick (#174)
  * stg pick --noapply no longer reverses patch order (#174)
  * Use stg version uses sys.executable to get Python version.
  * Repair stg repair with amended first patch (#163)
  * Repair corner cases where invalid patchnames could be generated by stg new,
    stg uncommit, etc. (#176)
  * stg mail could crash due to a misspelled reference (#178)
  * Zsh completion for stg refresh -p now completes against all patches (not
    just applied patches).
  * Zsh gains missing completion for stg push --noapply
  * Minor repair to help for stg float --noapply and stg push --noapply
  * Restore stg sink --nopush capability.
  * The new stg import --message-id option causes the Message-ID from imported
    emails to be included as the Message-Id trailer in the patch description
  * The new ‘stgit.import.message-id’ config option also enables the Message-Id
    trailer
  * stg import no longer creates “Message-Id” trailer by default when importing
    patches from email
  * StGit works with Python 3.10
  * stg version prints a more abbreviated Python version
    stg commit will no longer commit empty patches by default; the
  - -allow-empty option may be used to override this behavior (#158)
  * The stgit.main.main() function now takes an argv parameter and returns an
    int return code in most cases instead of calling sys.exit(), thus making
    main() a bit easier to use as an API.
  * Repair stack upgrade with stg branch --list (#155)
  * Repair crash in stg squash with out of order patches and no name specified (#157)
  * Zsh completions learn stg float --noapply option
  * Zsh completion for stg sink now allows multiple patches
  * Repair crash regression when using stgit.autosign
  * stg rebase learns --interactive; easily re-order, edit, squash, fixup, or
    delete patches via your editor
  * stg rebase learns --autostash; stash changes before the rebase and apply
    them after. Also configurable with the stgit.autostash configuration option
  * stg edit can now rename patches
  * stg edit gains helpful instructions
  * stg new learns --verbose, which includes a diff in the editor window
    (similar to git commit --verbose). This behavior is also configurable with
    the stgit.new.verbose configuration option
  * stg push and stg float learn --noapply option; allows patches to be
    reordered without updating worktree and deferring merge conflict resolution
  * stg edit, stg refresh, and stg new learn the --sign-by, --ack-by, and
  - -review-by options which allow those respective trailers' values to be
    specified by the user on the command line
  * Stack metadata version 5; stack metadata is moved from
    refs/heads/<branch>.stgit to refs/stacks/<branch> and the stack metadata
    file now uses a JSON format instead of the prior custom format; the stack
    metadata will be upgraded to v5 on first use of this version of StGit; like
    all stack metadata upgrades, this is a one-way auto-upgrade for existing
    stacks
  * Use setuptools instead of distutils for packaging
  * No git or python version checks in setup.py
  * Use different dynamic versioning system
  * Install stg executable as console_script entry point
  * More sophisticated search for bash.exe on Windows when running hooks
  * The editor window text for stg squash has been modified to mirror git’s
    behavior – the squash edit message now includes all commits
  * Binary diffs are no longer shown when with stg edit -d
  * Multiple trailers can now be added at once; this is now allowed, for
    example: stg edit --sign --review --ack
  * Update zsh completion for stg rebase to show local and remote heads (#102)
  * Zsh completions for commands with patch arguments now comprehend the effect
    of -b/--branch and -B/--ref-branch
  * Zsh completions now guard patch names–one less TAB press to complete patch
    names in certain contexts
  * stg import now extracts the Message-ID email header into the patch message
  * Repair crash when attempting to export empty patch
  * Exact command name matches are unambiguous
  * Exiting with an empty stg edit editor will now abort the edit; previously
    it would delete your commit message.
  * Repair completions when stg.series.description is enabled in config
  * Workaround child process reaping race on Windows
  * Repair crash with stg float --series when bad patch name in series
  * Repair zsh completion for stg float to accept multiple patch names
  * StGit GPG-signs patches when commit.gpgsign is set
  * Support core.hooksPath in git config
  * Add -C option for stg import and stg fold
  * Allow importing mail and series from urls
  * stg refresh --edit may also use --diff and --diff-opts
  * stg goto allows sha1 of a patch instead of patch name
  * Repair hang in stg pull -m, stg goto -m, and stg push -m
  * Repair stg mail to show diffstat of whole series
  * Repair MANIFEST.in to include AUTHORS.md and README.md files
  * Drop support for Python < 3.5
  * Remove previously deprecated stg publish command
  * Removed contrib scripts: stg-swallow, stg-fold-files-from, stg-dispatch,
    stg-whatchanged, and stg-show-old
  * The pre-commit hook is now run for stg refresh
  * New --spill option for stg refresh
  * Add stgit.series.description config option
  * Official support for Python versions up to 3.9
  * Stack metadata format 4. All metadata now kept in Git objects; no more
    stack state files in .git/patches. A one-way auto-upgrade to format version
    4 will occur when StGit commands are run on an existing StGit branch.
  * Use python3 in shebangs instead of python
  * contrib/stgbashprompt.sh is no longer executable
  * Internal docstrings now use reStructuredText instead of Epytext
  * Importing large patches is much, much faster
  * Other performance improvements when dealing with large patches
  * Repair diffstat when outside work tree root
  * Use encoded (string) environment variables on Windows
  * Fix stg pull when no upstream is configured
  * Fix refresh crash with path limiting and files added to index
  * Repair new with patchdescr.template crash
  * Repair log from worktree subdir with patches specified
  * Repair import allowing/generating duplicate patch names
  * Repair mail --auto to strip comments after addrs
* Tue Nov 10 2020 Dario Faggioli <dfaggioli@suse.com>
- Move to latest version, 0.23
  * `stg mail` was not working in v. 0.21, due to TLS issue. It
    does in 0.23
  * while there, update the URL
- Add patch stgbashprompt-noexec.patch
  * so rpmlint won't complain about executable without '#!'
* Fri Jan 17 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Create .pyc files reproducibly (boo#1049186)
* Mon Jan 13 2020 tiwai@suse.de
- Revive asciidoc; will be replaced or dropped later, depending on
  the general solution of asciidoc support on TW
* Mon Jan 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.21:
  * Build reproducibility repairs (Thanks reproducible-builds.org team!)
  * Faster handling of large patches (#44)
  * Python can now be run with optimizations (python -O)
  * stg log now prints trailing newline
  * Improved command line option parsing for stg log
* Mon Jan 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to python3 to build
- Disable documentation generating using asciidoc as that requires
  python2
* Thu Aug  8 2019 Mikhail Terekhov <termim@gmail.com>
- updated to version 0.19
  - - Python 3 support. StGit supports Python 2.6, 2.7, 3.3, 3.4, 3.5, 3.6,
    and 3.7. PyPy interpreters are also supported.
  - - Submodules are now ignored when checking if working tree is
    clean. Submodules are also not included by default when refreshing a
    patch.
  - - Config booleans are now parsed similarly to git-config.
  - - contrib/stgit.el is now licenced with GPLv2.
  - - Repair handling of emails with utf-8 bodies containing latin-1
    characters. Also correctly decode email headers containing quoted encoded
    words.
  - - StGit's version is now correct/available the release archive.
  - - Add continuous integration (travis-ci) and code coverage (coveralls) support.
  - - Many new test cases were added.
- updated to version 0.18
  - - commit-msg hook support for easier integration with Gerrit, allowing a
    Change-Id line to be inserted in the commit message.
  - - stg mail improvements for Suggested-by: tag and auto generation of Cc
    for the cover letter based on all tags in the series.
  - - stg mail bash completion for the -to, -cc and -bcc options based on
    the content of the [mail "alias"] section of GIT configuration.
  - - stg edit -review option to add a Reviewed-by: tag.
  - - stg pop -spill functionality to allow popping a patch from the stack
    while keeping its modification in the tree.
  - - Various fixes and test coverage improvements.
  - - Project page details updated (gna.org has been shut down).
* Wed Mar 30 2016 mpluskal@suse.com
- Use url for source
- Add gpg signature
- Cleanup spec file with spec-cleaner
* Wed Oct  2 2013 david.bahi@emc.com
- updated to version 0.17.1
  - - Fix dirty index errors when resolving conflicts.
  - - Test suite improvements.
  - - Print tracebacks to stderr.
  - - Run test suite in parallel.
  - - Fix --authdate date parsing.
- changes from version 0.16 to 0.17
  - - Make refresh warn when the index is dirty
  - - Template updates to not hardcode whitespace
  - - Properly generate mbox formats when attaching patches
  - - Added new option to attach and inline patches when sending mail
  - - Various bugfixes and tiny improvements
* Tue Feb 28 2012 tiwai@suse.de
- updated to version 0.16:
  * Several improvements to the Emacs mode (stgit.el).
  * UI adjustments to better match the Git commands.
  * "stg status" is an alias for "git status".
  * "stg reset --hard" behaves similarly to the corresponding git
    command and option.
  * "stg branch --cleanup" option to remove the StGit metadata for
    a given branch.
  * "stg mail" can use "git send-email" directly.
  * Vim syntax highlighting for StGit commit messages.
  * Many bug-fixes.
* Mon Aug 10 2009 tiwai@suse.de
- fix build with older distros
- build as noarch for Factory
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Tue Jun 10 2008 tiwai@suse.de
- updated to version 0.14.3:
  a maintenance release including bug-fixes for the "refresh"
  command, handling of file names with non-ASCII characters and
  user interface enhancements for "export" and "sync"
* Mon Apr 14 2008 tiwai@suse.de
- updated to version 0.14.2:
  * a maintenance release including bug-fixes and a few user
    interface enhancements
* Fri Jan 11 2008 tiwai@suse.de
- updated to version 0.14.1:
  * Fixed typo in the required version of Python
- updated to version 0.14:
  * Support for correctly running StGIT in subdirectories
  * 'repair' command for fixing an StGIT repository modified by
    GIT commands such as 'commit', 'pull', 'merge' or 'rebase'
  * 'edit' command for editing both the patch description and diff
  * Support for SMTP over TLS
  * Support for MIME multipart e-mail templates
  * '--attach' option to the 'mail' command to send a patch
    attached rather than inline
  * Diff statistics and shortlog added to the cover e-mail
    template
  * '--sign/ack' options to the 'import' and 'new' commands
  * '--number' to the 'log' command for limiting the output
  * Support for binary files in patches
  * Support for detached HEAD
  * Refactoring of some modules with better support for debugging
  * Many bug-fixes
* Thu Jul 26 2007 tiwai@suse.de
- updated to version 0.13:
  * Documentation directory with man pages
  * Safety checks for the 'rebase' command
  * Various contrib scripts
  * 'cp' command to copy files
  * 'sink' command to complement 'float'
  * '--diff-opts' option to some commands for passing
    additional arguments to 'git-diff-*'
  * 'stgit.mail.prefix' configuration option for the default
    'mail --prefix' value
  * Interractive 2-way merging via xxdiff or emacs (previously,
    only 3-way merging had this feature)
  * Slightly changed behaviour to the 'patches' command when no
    argument is given to show the patches touching the locally
    modified files
  * Correct importing of multipart e-mails
  * '--unrelated' option to 'mail' to send patches unthreaded
    and without sequence numbering
  * '--update' option to 'refresh' to only check in the files
    already modified by the current patch (similar to
    'pick --update')
  * '--keep' option to 'goto' (though it only works for patch
    popping)
  * '--expose' option to 'pick' to append the picked commit id
    to the log (similar to the 'git cherry-pick -x' command)
  * The 'new' command can automatically generate the patch name'
    from the given log
  * 'uncommit' can generate patches up to a given commit id
  * Bug fixes
* Mon Apr  2 2007 tiwai@suse.de
- updated to verison 0.12.1:
  * Allow StGIT to run when there is no user information
    configured
  * Use 'git-pull' rather than 'git-fetch' by default
  * Fix the 'mail' command to parse multiple-lines address
    headers
  * Fix the alias check in the 'stg mail --bcc' command
  * Add '--merged' option to rebase
  * Add '--url' option to 'import' to import a file directly
    from the network
  * Add '--author' option to 'series'
* Wed Feb  7 2007 tiwai@suse.de
- updated to version 0.12:
  * New 'rebase' command to change the base of an StGIT stack
  * New 'hide' and 'unhide' commands to act on the patches in a
    series.
  * New 'sync' command to synchronise same patches in different
    branches
  * New 'assimilate' command to transform GIT (accidental)
    commits at the top of the stack in StGIT patches
  * Re-worked pulling logic to use the branch information stored
    in the .git/config file
  * Abbreviation for StGIT commands
  * Correct encoding of the e-mail headers and body
  * Support for importing multipart e-mails and mbox files
  * Configuration read from the GIT config files rather than
    stgitrc
  * Patch ranges can be specified for 'export'
  * '--missing' option for 'series' to list the patches on a
    branch which are missing in current
  * StGIT bash completion script
  * Bug fixes
* Tue Jan  9 2007 tiwai@suse.de
- updated to version 0.11:
  * new 'float' command
  * patch history support, accessible through log command
  * automatically generate patch names
  * many new options, bug fixes
* Wed Sep 20 2006 tiwai@suse.de
- initial version: 0.10
